==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/WeightedCloseIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { WeightedCloseIndicatorStrategy } from "./WeightedCloseIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var WeightedCloseIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicator, _super);
    function WeightedCloseIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicator.prototype.get_u7 = function () {
        return new WeightedCloseIndicatorStrategy();
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "u7", {
        get: function () {
            return this.get_u7();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.prototype.get_uy = function () {
        return WeightedCloseIndicator.$;
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.$t = markType(WeightedCloseIndicator, 'WeightedCloseIndicator', ItemwiseStrategyBasedIndicator.$);
    return WeightedCloseIndicator;
}(ItemwiseStrategyBasedIndicator));
export { WeightedCloseIndicator };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/WeightedCloseIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { WeightedCloseIndicatorStrategy } from "./WeightedCloseIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var WeightedCloseIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicator, _super);
    function WeightedCloseIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicator.prototype.get_vb = function () {
        return new WeightedCloseIndicatorStrategy();
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "vb", {
        get: function () {
            return this.get_vb();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.prototype.get_u2 = function () {
        return WeightedCloseIndicator.$;
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.$t = markType(WeightedCloseIndicator, 'WeightedCloseIndicator', ItemwiseStrategyBasedIndicator.$);
    return WeightedCloseIndicator;
}(ItemwiseStrategyBasedIndicator));
export { WeightedCloseIndicator };
